@@ -38,7 +38,7 @@ MooX::Role::JSON_LD - Easily provide JSON-LD mark-up for your objects.
 
 =head1 DESCRIPTION
 
-This role allows you to easily add a method you your class that produces
+This role allows you to easily add a method to your class that produces
 JSON-LD representing an instance of your class.
 
 To do this, you need to do three things:
@@ -144,24 +144,27 @@ package MooX::Role::JSON_LD;
 use 5.6.0;
 
 use Moo::Role;
+
 use Carp;
 use JSON::MaybeXS;
+use MRO::Compat;
 use Types::Standard qw[ArrayRef HashRef InstanceOf Str is_CodeRef is_HashRef is_Ref is_Object];
 
-our $VERSION = '0.0.15';
+our $VERSION = '0.0.16';
 
 requires qw[json_ld_type json_ld_fields];
 
 has json_ld_encoder => (
   isa => InstanceOf[ qw/ Cpanel::JSON::XS JSON JSON::PP JSON::XS /],
-  is  => 'ro',
-  lazy => 1,
+  is  => 'lazy',
   builder => '_build_json_ld_encoder',
 );
 
 sub _build_json_ld_encoder {
-  return JSON->new->canonical->utf8->space_after->indent->pretty;
-}
+    my ($self) = @_;
+    return $self->maybe::next::method ||
+        JSON->new->canonical->utf8->space_after->indent->pretty;
+};
 
 has context => (
   isa => Str | HashRef | ArrayRef,
